/**
 * Represents a float-valued filter parameter.
 */
public class FloatFilterParam extends FilterParam {
	private final String name;
	private final float min;
	private final float max;
	private float value;
	
	// ### INIT ###
	
	/**
	 * @param name	the name of this parameter, as it will be displayed in the GUI
	 * @param min	the minimum value of this parameter (inclusive),
	 * 				or <tt>Float.MIN_VALUE</tt> to indicate an unbounded minimum
	 * @param max	the maximum value of this parameter (inclusive),
	 * 				or <tt>Float.MAX_VALUE</tt> to indicate an unbounded maximum
	 */
	public FloatFilterParam(String name, float min, float max) {
		this(name, min, max, min);
	}
	
	/**
	 * @param name	the name of this parameter, as it will be displayed in the GUI
	 * @param min	the minimum value of this parameter (inclusive),
	 * 				or <tt>Float.MIN_VALUE</tt> to indicate an unbounded minimum
	 * @param max	the maximum value of this parameter (inclusive),
	 * 				or <tt>Float.MAX_VALUE</tt> to indicate an unbounded maximum
	 * @param value	the initial value of this parameter
	 */
	public FloatFilterParam(String name, float min, float max, float value) {
		this.name = name;
		this.min = min;
		this.max = max;
		this.setValue(value);
	}
	
	// ### ACCESSORS ###
	
	public String getName() {
		return this.name;
	}
	
	public float getMin() {
		return this.min;
	}
	
	public float getMax() {
		return this.max;
	}
	
	public float getValue() {
		return this.value;
	}
	
	public void setValue(float value) {
		if (value < this.min)
			throw new IllegalArgumentException(
				"value out of range (value < min): "+value+" < "+min);
		if (value > this.max)
			throw new IllegalArgumentException(
				"value out of range (value > max): "+value+" > "+max);
		this.value = value;
	}
}